==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/hr/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Modul je uspješno onemogućen!',
    '
Module successfully enabled!
' => 'Modul je uspješno omogućen!',
    '--- Disable module: {moduleId} ---

' => '--- Onemogući modul: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Omogući modul: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Aktiviraj</strong> vašu profesionalnu verziju',
    'Add purchased module by licence key' => 'Dodajte kupljeni modul licenčnim ključem',
    'All {moduleId} module content will be deleted. Continue?' => 'Sav {moduleId} modul sadržaj će biti izbrisan. Nastaviti?',
    'Buy' => 'Kupi',
    'Buy (%price%)' => 'Kupi (%price%)',
    'Could not connect to licence server!' => 'Ne mogu se povezati s poslužiteljem licenci!',
    'Could not extract module!' => 'Ne mogu izdvojiti modul!',
    'Could not remove old module path!' => 'Nije moguće ukloniti staru putanju modula!',
    'Could not update licence. Error: ' => 'Nije moguće ažurirati licencu. Pogreška:',
    'Download of module failed!' => 'Preuzimanje modula nije uspjelo!',
    'Edit licence' => 'Uredi licencu',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Ako je ovaj modul dodatno označen kao <strong>"Zajednica" </strong> projektni tim HumHub niti ga testira niti nadgleda.',
    'Install' => 'Instaliraj',
    'Installed' => 'Instalirano',
    'Installing module...' => 'Instaliram modul...',
    'Latest version:' => 'Zadnja verzija:',
    'Licence Key:' => 'Licencni ključ:',
    'Licence key' => 'Ključ licence',
    'Licenced for max. {number} users.' => 'Licencirano za max. Broj korisnika: {number}.',
    'Licenced to:' => 'Licencirano za:',
    'Marketplace' => 'Trgovina',
    'Max. users:' => 'Maks. korisnika:',
    'Module directory %modulePath% is not writeable!' => 'Direktorij modula %modulePath% nije za pisanje!',
    'Module download failed! (%error%)' => 'Preuzimanje modula nije uspjelo! (%error%)',
    'Module not found or activated!
' => 'Modul nije pronađen ili aktiviran!',
    'Module not found!
' => 'Modul nije pronađen!',
    'More info' => 'Više info',
    'No compatible module version found!' => 'Nisu pronađene kompatibilne verzije modula!',
    'No license key? Find out more about the {pro} or contact us.' => 'Nemate licencni ključ? Saznajte više o {pro} ili nas kontaktirajte.',
    'No purchased modules found!' => 'Nisu pronađeni kupljeni moduli!',
    'Ok' => 'Ok',
    'Professional Edition is activated!' => 'Aktivirano je profesionalno izdanje!',
    'Register' => 'Registriraj',
    'Remove licence key' => 'Uklonite ključ licence',
    'Save and update' => 'Spremi i ažuriraj',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Projekt HumHub ne jamči funkcionalnost, kvalitetu ili kontinuirani razvoj ovog modula.',
    'Third-party' => 'Treća strana',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Moduli treće strane nisu obuhvaćeni sporazumima Professional Edition.',
    'Third-party disclaimer' => 'Odricanje treće strane',
    'This Module was developed by a third-party.' => 'Ovaj je modul razvila treća strana.',
    'Update' => 'Ažuriranje',
    'Upgrade to Professional Edition' => 'Nadogradite na profesionalno izdanje',
    'Version:' => 'Verzija:',
    '
No active Professional Edition license found!
' => '',
    '
PROFESSIONAL EDITION
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!
' => '',
    'Featured' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/hr/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Modul je uspješno onemogućen!',
    '
Module successfully enabled!
' => 'Modul je uspješno omogućen!',
    '--- Disable module: {moduleId} ---

' => '--- Onemogući modul: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Omogući modul: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Aktiviraj</strong> vašu profesionalnu verziju',
    'Activated' => 'Aktivirano',
    'Add purchased module by licence key' => 'Dodajte kupljeni modul licenčnim ključem',
    'All' => 'Sve',
    'All {moduleId} module content will be deleted. Continue?' => 'Sav {moduleId} modul sadržaj će biti izbrisan. Nastaviti?',
    'Buy' => 'Kupi',
    'Buy (%price%)' => 'Kupi (%price%)',
    'Configure' => 'Konfiguriraj',
    'Could not connect to licence server!' => 'Ne mogu se povezati s poslužiteljem licenci!',
    'Could not extract module!' => 'Ne mogu izdvojiti modul!',
    'Could not find requested module!' => 'Traženi modul nije pronađen.',
    'Could not remove old module path!' => 'Nije moguće ukloniti staru putanju modula!',
    'Could not update licence. Error: ' => 'Nije moguće ažurirati licencu. Pogreška:',
    'Download of module failed!' => 'Preuzimanje modula nije uspjelo!',
    'Edit licence' => 'Uredi licencu',
    'General Settings' => 'Općenite postavke',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Ako je ovaj modul dodatno označen kao <strong>"Zajednica" </strong> projektni tim HumHub niti ga testira niti nadgleda.',
    'Information' => 'Informacija',
    'Install' => 'Instaliraj',
    'Installed' => 'Instalirano',
    'Latest version:' => 'Zadnja verzija:',
    'Licence Key:' => 'Licencni ključ:',
    'Licence key' => 'Ključ licence',
    'Licenced for max. {number} users.' => 'Licencirano za max. Broj korisnika: {number}.',
    'Licenced to:' => 'Licencirano za:',
    'Marketplace' => 'Trgovina',
    'Max. users:' => 'Maks. korisnika:',
    'Module directory %modulePath% is not writeable!' => 'Direktorij modula %modulePath% nije za pisanje!',
    'Module download failed! (%error%)' => 'Preuzimanje modula nije uspjelo! (%error%)',
    'Module not found or activated!
' => 'Modul nije pronađen ili aktiviran!',
    'Module not found!
' => 'Modul nije pronađen!',
    'More info' => 'Više info',
    'New' => 'Novi',
    'No compatible module version found!' => 'Nisu pronađene kompatibilne verzije modula!',
    'No license key? Find out more about the {pro} or contact us.' => 'Nemate licencni ključ? Saznajte više o {pro} ili nas kontaktirajte.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Još nijedan modul nije instaliran. Instalirajte neke za poboljšanje funkcionalnosti!',
    'No purchased modules found!' => 'Nisu pronađeni kupljeni moduli!',
    'Ok' => 'Ok',
    'Professional Edition is activated!' => 'Aktivirano je profesionalno izdanje!',
    'Register' => 'Registriraj',
    'Remove licence key' => 'Uklonite ključ licence',
    'Save and update' => 'Spremi i ažuriraj',
    'Search' => 'Pretraži',
    'Settings' => 'Postavke',
    'Tags' => 'Tagovi',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Projekt HumHub ne jamči funkcionalnost, kvalitetu ili kontinuirani razvoj ovog modula.',
    'Third-party' => 'Treća strana',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Moduli treće strane nisu obuhvaćeni sporazumima Professional Edition.',
    'Third-party disclaimer' => 'Odricanje treće strane',
    'This Module was developed by a third-party.' => 'Ovaj je modul razvila treća strana.',
    'Update' => 'Ažuriranje',
    'Update successful' => 'Ažuriranje uspješno',
    'Upgrade to Professional Edition' => 'Nadogradite na profesionalno izdanje',
    'Version:' => 'Verzija:',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate' => '',
    'Activate now' => '',
    'Add Licence Key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Search...' => '',
    'Stop updating' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
